==> openejb-jee-accessors-4.6.0.2-sources.jar: org/apache/openejb/sxc/HandlerChainsXml.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
    * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.sxc;

import org.metatype.sxc.util.XoXMLStreamReaderImpl;
import org.apache.openejb.jee.Adapters;
import org.apache.openejb.jee.HandlerChains;
import org.apache.openejb.jee.HandlerChains$JAXB;
import org.apache.openejb.loader.IO;

import javax.xml.stream.XMLStreamReader;
import javax.xml.transform.stream.StreamResult;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;

/**
 * @version $Rev$ $Date$
 */
public class HandlerChainsXml {

    public static HandlerChains unmarshal(InputStream inputStream) throws Exception {
        return Sxc.unmarshalJavaee(new HandlerChains$JAXB(), inputStream);
    }

    public static HandlerChains unmarshal(URL url) throws Exception {
        final InputStream inputStream = IO.read(url);
        try {
            final XMLStreamReader filter = Sxc.prepareReader(inputStream);
            synchronized (Adapters.handlerChainsStringQNameAdapterAdapter) { // few threads on it so synchronized > lock
                Adapters.handlerChainsStringQNameAdapterAdapter.setNamespaceContext(filter.getNamespaceContext());
                try {
                    return Sxc.unmarhsal(new HandlerChains$JAXB(), new XoXMLStreamReaderImpl(filter));
                } finally {
                    Adapters.handlerChainsStringQNameAdapterAdapter.setNamespaceContext(null);
                }
            }
        } finally {
            IO.close(inputStream);
        }
    }

    public static void marshal(HandlerChains handlerChains, OutputStream outputStream) throws Exception {
        Sxc.marshal(new HandlerChains$JAXB(), handlerChains, new StreamResult(outputStream));
    }
}

==> openejb-jee-accessors-4.7.4-sources.jar: org/apache/openejb/sxc/HandlerChainsXml.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
    * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.sxc;

import org.apache.openejb.jee.Adapters;
import org.apache.openejb.jee.HandlerChains;
import org.apache.openejb.jee.HandlerChains$JAXB;
import org.apache.openejb.loader.IO;
import org.metatype.sxc.util.XoXMLStreamReaderImpl;

import javax.xml.stream.XMLStreamReader;
import javax.xml.transform.stream.StreamResult;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;

/**
 * @version $Rev$ $Date$
 */
public class HandlerChainsXml {

    public static HandlerChains unmarshal(final InputStream inputStream) throws Exception {
        return Sxc.unmarshalJavaee(new HandlerChains$JAXB(), inputStream);
    }

    public static HandlerChains unmarshal(final URL url) throws Exception {
        final InputStream inputStream = IO.read(url);
        try {
            final XMLStreamReader filter = Sxc.prepareReader(inputStream);
            synchronized (Adapters.handlerChainsStringQNameAdapterAdapter) { // few threads on it so synchronized > lock
                Adapters.handlerChainsStringQNameAdapterAdapter.setNamespaceContext(filter.getNamespaceContext());
                try {
                    return Sxc.unmarhsal(new HandlerChains$JAXB(), new XoXMLStreamReaderImpl(filter));
                } finally {
                    Adapters.handlerChainsStringQNameAdapterAdapter.setNamespaceContext(null);
                }
            }
        } finally {
            IO.close(inputStream);
        }
    }

    public static void marshal(final HandlerChains handlerChains, final OutputStream outputStream) throws Exception {
        Sxc.marshal(new HandlerChains$JAXB(), handlerChains, new StreamResult(outputStream));
    }
}
